==> dde-shell_2.0.3.tar.xz: BUILD/panels/notification/center/translations/org.deepin.ds.notificationcenter_ko.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>GroupNotify</name>
    <message>
        <source>Clear All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NotifyHeader</name>
    <message>
        <source>Notification Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NotifySetting</name>
    <message>
        <source>Unpin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notification Setting</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>notifycenter::AppNotifyItem</name>
    <message>
        <source>Just now</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 minutes ago</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 hour ago</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 hours ago</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yesterday </source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> dde-shell_2.0.15.tar.xz: BUILD/panels/notification/center/translations/org.deepin.ds.notificationcenter_ko.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>GroupNotify</name>
    <message>
        <source>Clear All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>More</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NotifyCenter</name>
    <message>
        <source>No recent notifications</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NotifyHeader</name>
    <message>
        <source>Notification Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>More</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NotifySetting</name>
    <message>
        <source>Unpin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notification Setting</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NotifyViewDelegate</name>
    <message>
        <source>Clean All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>notifycenter::AppNotifyItem</name>
    <message>
        <source>Just now</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
